searchNodes=[{"doc":"ExOtp allows you to create One-Time-Passwords, which can be either Time-based One-Time Passwords(TOTP) and Counter based OTPs(via HMAC-based One Time Passwords(HOTP)). The library is primarily based on the PyOTP , and almost exactly mirrors their API as well. It follows the MFA standards defined in RFC4226 (HOTP: an Hmac-Based One-Time Password Algorithm) and RFC6238 (TOTP: Time-Based One-Time Password Algorithm). The library provides the following features: Generate TOTP or Counter based HOTP Generate QR codes for OTPs Generate random secret values(if required) Usage TOTP Create a TOTP object using either a random secret or a user-provided secret as follows: Example: secret = ExOtp . random_secret ( ) #=&gt; &quot;uapgaiacdaptafbu&quot; totp = ExOtp . create_totp ( secret , 30 ) # Specify interval for which the OTP will be valid. #=&gt; %ExOtp.Totp{ # base: %ExOtp.Base{ # digest: :sha, # digits: 6, # secret: &quot;OVQXAZ3BNFQWGZDBOB2GCZTCOU======&quot; # }, # interval: 30 #} Generate an otp using the totp object, for a given datetime value: Example: otp = ExOtp . generate_totp ( totp , DateTime . utc_now ( ) ) #=&gt; &quot;967372&quot; Finally, you can check if the otp is valid using the otp and totp objects: Example: ExOtp . valid_totp? ( totp , otp , DateTime . utc_now ( ) ) #=&gt; true HOTP Create a HOTP object using either a random secret or a user-provided secret as follows: Example: secret = ExOtp . random_secret ( ) #=&gt; &quot;uapgaiacdaptafbu&quot; hotp = ExOtp . create_hotp ( secret , 30 ) # Specify initial count #=&gt; %ExOtp.Hotp{ # base: %ExOtp.Base{ # digest: :sha, # digits: 6, # secret: &quot;OVQXAZ3BNFQWGZDBOB2GCZTCOU======&quot; # }, # initial_count: 0 #} Generate an otp using the hotp object, for a given datetime value: Example: otp = ExOtp . generate_hotp ( hotp , DateTime . utc_now ( ) ) #=&gt; &quot;268374&quot; Finally, you can check if the otp is valid using the otp and hotp objects: Example: ExOtp . valid_hotp? ( hotp , otp , 0 ) # Specify counter value #=&gt; true QR Code(Optional) Generate the provision URI for use with a QR code scanner built into MFA apps such as Google Authenticator. Generate the QR code using the EQRCode libraby, which is an optional dependency. Given a totp object and an otp , you can generate the QR code using: Example: totp |&gt; ExOtp . provision_uri_totp ( otp , &quot;test:shubham@google.com&quot; , issuer_name : &quot;test&quot; ) |&gt; ExOtp . generate_qr_code ( &quot;code.svg&quot; ) #=&gt; 09:51:17.102 [info] QR code written to file: code.svg","ref":"ExOtp.html","title":"ExOtp","type":"module"},{"doc":"","ref":"ExOtp.html#create_hotp/2","title":"ExOtp.create_hotp/2","type":"function"},{"doc":"","ref":"ExOtp.html#create_totp/2","title":"ExOtp.create_totp/2","type":"function"},{"doc":"","ref":"ExOtp.html#generate_hotp/2","title":"ExOtp.generate_hotp/2","type":"function"},{"doc":"","ref":"ExOtp.html#generate_qr_code/2","title":"ExOtp.generate_qr_code/2","type":"function"},{"doc":"","ref":"ExOtp.html#generate_totp/3","title":"ExOtp.generate_totp/3","type":"function"},{"doc":"","ref":"ExOtp.html#provision_uri_hotp/3","title":"ExOtp.provision_uri_hotp/3","type":"function"},{"doc":"","ref":"ExOtp.html#provision_uri_totp/3","title":"ExOtp.provision_uri_totp/3","type":"function"},{"doc":"","ref":"ExOtp.html#random_secret/1","title":"ExOtp.random_secret/1","type":"function"},{"doc":"","ref":"ExOtp.html#valid_hotp?/3","title":"ExOtp.valid_hotp?/3","type":"function"},{"doc":"","ref":"ExOtp.html#valid_totp?/4","title":"ExOtp.valid_totp?/4","type":"function"},{"doc":"Base file containing common functions for generating the One-time Password algorithms.","ref":"ExOtp.Base.html","title":"ExOtp.Base","type":"module"},{"doc":"Function to generate the OTP, given an input.","ref":"ExOtp.Base.html#generate_otp/2","title":"ExOtp.Base.generate_otp/2","type":"function"},{"doc":"","ref":"ExOtp.Base.html#new/1","title":"ExOtp.Base.new/1","type":"function"},{"doc":"Function to validate the attributes for the Base struct.","ref":"ExOtp.Base.html#validate/1","title":"ExOtp.Base.validate/1","type":"function"},{"doc":"","ref":"ExOtp.Base.html#t:t/0","title":"ExOtp.Base.t/0","type":"type"},{"doc":"This module implements the behaviour OTP classes.","ref":"ExOtp.Behaviour.html","title":"ExOtp.Behaviour","type":"behaviour"},{"doc":"Function to generate the OTP for the given timestamp value, and an optional integer value whic could be the interval(for Totp) or counter(for Hotp).","ref":"ExOtp.Behaviour.html#c:at/2","title":"ExOtp.Behaviour.at/2","type":"callback"},{"doc":"This function accepts an integer and secret, and returns either a TOTP or HOTP struct","ref":"ExOtp.Behaviour.html#c:new/2","title":"ExOtp.Behaviour.new/2","type":"callback"},{"doc":"Function to generate the URI which can be used to generate QR codes, which can be read by 2FA apps such as Google Authenticator.","ref":"ExOtp.Behaviour.html#c:provision_uri/3","title":"ExOtp.Behaviour.provision_uri/3","type":"callback"},{"doc":"Function to check if the input otp is valid for the given algorithm(Totp or Hotp) and the timestamp. Returns true if the otp is valid and false otherwise.","ref":"ExOtp.Behaviour.html#c:valid?/3","title":"ExOtp.Behaviour.valid?/3","type":"callback"},{"doc":"Function to validate the attributes of the input struct, which can be either a Totp or Hotp object. Returns the struct if all attributes are valid and raises an error otherwise.","ref":"ExOtp.Behaviour.html#c:validate/1","title":"ExOtp.Behaviour.validate/1","type":"callback"},{"doc":"Module for the HMAC based One-time Password algorithm.","ref":"ExOtp.Hotp.html","title":"ExOtp.Hotp","type":"module"},{"doc":"Callback implementation for ExOtp.Behaviour.at/2 .","ref":"ExOtp.Hotp.html#at/2","title":"ExOtp.Hotp.at/2","type":"function"},{"doc":"Callback implementation for ExOtp.Behaviour.new/2 .","ref":"ExOtp.Hotp.html#new/2","title":"ExOtp.Hotp.new/2","type":"function"},{"doc":"Callback implementation for ExOtp.Behaviour.provision_uri/3 .","ref":"ExOtp.Hotp.html#provision_uri/3","title":"ExOtp.Hotp.provision_uri/3","type":"function"},{"doc":"Callback implementation for ExOtp.Behaviour.valid?/3 .","ref":"ExOtp.Hotp.html#valid?/3","title":"ExOtp.Hotp.valid?/3","type":"function"},{"doc":"Callback implementation for ExOtp.Behaviour.validate/1 .","ref":"ExOtp.Hotp.html#validate/1","title":"ExOtp.Hotp.validate/1","type":"function"},{"doc":"","ref":"ExOtp.Hotp.html#t:t/0","title":"ExOtp.Hotp.t/0","type":"type"},{"doc":"Module for the Time-based One-time Password algorithm.","ref":"ExOtp.Totp.html","title":"ExOtp.Totp","type":"module"},{"doc":"","ref":"ExOtp.Totp.html#at/3","title":"ExOtp.Totp.at/3","type":"function"},{"doc":"Callback implementation for ExOtp.Behaviour.new/2 .","ref":"ExOtp.Totp.html#new/2","title":"ExOtp.Totp.new/2","type":"function"},{"doc":"Callback implementation for ExOtp.Behaviour.provision_uri/3 .","ref":"ExOtp.Totp.html#provision_uri/3","title":"ExOtp.Totp.provision_uri/3","type":"function"},{"doc":"","ref":"ExOtp.Totp.html#valid?/4","title":"ExOtp.Totp.valid?/4","type":"function"},{"doc":"Callback implementation for ExOtp.Behaviour.validate/1 .","ref":"ExOtp.Totp.html#validate/1","title":"ExOtp.Totp.validate/1","type":"function"},{"doc":"","ref":"ExOtp.Totp.html#t:t/0","title":"ExOtp.Totp.t/0","type":"type"},{"doc":"Module to display a custom message when a parameter receives an invalid value.","ref":"ExOtp.Errors.InvalidParam.html","title":"ExOtp.Errors.InvalidParam","type":"exception"},{"doc":"Callback implementation for Exception.message/1 .","ref":"ExOtp.Errors.InvalidParam.html#message/1","title":"ExOtp.Errors.InvalidParam.message/1","type":"function"},{"doc":"Module to display a custom message when there is a missing dependency.","ref":"ExOtp.Errors.MissingDependency.html","title":"ExOtp.Errors.MissingDependency","type":"exception"},{"doc":"Callback implementation for Exception.message/1 .","ref":"ExOtp.Errors.MissingDependency.html#message/1","title":"ExOtp.Errors.MissingDependency.message/1","type":"function"}]